dem

package module
v0.0.0-...-1343968 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2021 License: MIT Imports: 7 Imported by: 0

README

Datastore Emulator UI

I wrote in Go what can display data of Datastore Emulator. We didn't introduce a big framework to make io easier for you to change.

I have no intention of using it for anything other than the emulator, but it may be possible if I devise something around authentication.

Install

go install github.com/secondarykey/dem/_cmd/dem-view

or dem release.

Run

$ dem-view

Boot on port 8088(default) The list of endpoints is saved in $HOME/.dem.gob(default)

Read Help for details on the arguments.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Listen

func Listen(opts ...config.ViewerOption) error

func RemoveEntity

func RemoveEntity(names ...string) error

func SetConsoleOptions

func SetConsoleOptions(opts ...config.ConsoleOption) error

func ViewEntity

func ViewEntity(names ...string) error

func ViewKind

func ViewKind(names ...string) error

Types

This section is empty.

Directories

Path Synopsis
dem-tool command
dem-view command

Jump to